/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *  http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.gravitino.catalog.hadoop;

import java.util.Objects;
import org.apache.gravitino.connector.capability.Capability;
import org.apache.gravitino.connector.capability.CapabilityResult;

public class HadoopCatalogCapability implements Capability {
  @Override
  public CapabilityResult managedStorage(Scope scope) {
    if (Objects.requireNonNull(scope) == Scope.SCHEMA) {
      return CapabilityResult.SUPPORTED;
    }
    return CapabilityResult.unsupported(
        String.format("Hadoop catalog does not support managed storage for %s.", scope));
  }

  @Override
  public CapabilityResult specificationOnName(Scope scope, String name) {
    CapabilityResult capabilityResult = Capability.super.specificationOnName(scope, name);
    if (!capabilityResult.supported()) {
      return capabilityResult;
    }

    if (name.contains("/")) {
      return CapabilityResult.unsupported(
          String.format("Hadoop catalog does not support '/' in the name for %s.", scope));
    }

    return CapabilityResult.SUPPORTED;
  }
}
