/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *  http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.gravitino.cli;

import static org.junit.jupiter.api.Assertions.assertFalse;
import static org.junit.jupiter.api.Assertions.assertTrue;

import org.junit.jupiter.api.Test;

class TestsPrivileges {

  @Test
  void testValidPrivilege() {
    assertTrue(Privileges.isValid(Privileges.CREATE_CATALOG));
    assertTrue(Privileges.isValid(Privileges.CREATE_TABLE));
    assertTrue(Privileges.isValid(Privileges.CONSUME_TOPIC));
    assertTrue(Privileges.isValid(Privileges.MANAGE_GRANTS));
  }

  @Test
  void testInvalidPrivilege() {
    assertFalse(Privileges.isValid("non_existent_privilege"));
    assertFalse(Privileges.isValid("create_database"));
  }

  @Test
  void testNullPrivilege() {
    assertFalse(Privileges.isValid(null));
  }

  @Test
  void testEmptyPrivilege() {
    assertFalse(Privileges.isValid(""));
  }
}
